@@ -7,7 +7,7 @@ use Mojo::JSON;
 use Mojo::Util;
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '2.20';
+our $VERSION = '2.22';
 my $X_RE = qr{^x-};
 
 has route     => sub {undef};
@@ -121,10 +121,9 @@ sub _add_routes {
       die qq([OpenAPI] Route name "$name" is not unique.) if $name and $uniq{r}{$name}++;
 
       if (!$to and $name) {
-        $r = $self->route->root->find($name)
-          or die "[OpenAPI] Could not find route by name '$name'.";
-        warn "[OpenAPI] Found existing route by name '$name'.\n" if DEBUG;
-        $self->route->add_child($r);
+        $r = $self->route->root->find($name);
+        warn "[OpenAPI] Found existing route by name '$name'.\n" if DEBUG and $r;
+        $self->route->add_child($r)                              if $r;
       }
       if (!$r) {
         my $route_path = $self->_openapi_path_to_route_path($http_method, $openapi_path);
@@ -381,7 +380,8 @@ Mojolicious::Plugin::OpenAPI - OpenAPI / Swagger plugin for Mojolicious
   }, "echo";
 
   # Load specification and start web server
-  plugin OpenAPI => {url => "data:///spec.json"};
+  # Use "v3" instead of "v2" for "schema" if you are using OpenAPI v3
+  plugin OpenAPI => {url => "data:///spec.json", schema => "v2"};
   app->start;
 
   __DATA__
@@ -409,20 +409,18 @@ Mojolicious::Plugin::OpenAPI - OpenAPI / Swagger plugin for Mojolicious
     }
   }
 
-See L<Mojolicious::Plugin::OpenAPI::Guides::Tutorial> for a tutorial on how to
+See L<Mojolicious::Plugin::OpenAPI::Guides::OpenAPIv2> or
+L<Mojolicious::Plugin::OpenAPI::Guides::OpenAPIv3> for tutorials on how to
 write a "full" app with application class and controllers.
 
 =head1 DESCRIPTION
 
 L<Mojolicious::Plugin::OpenAPI> is L<Mojolicious::Plugin> that add routes and
 input/output validation to your L<Mojolicious> application based on a OpenAPI
-(Swagger) specification.
+(Swagger) specification. This plugin supports both version L<2.0|/schema> and
+L<3.x|/schema>, though 3.x I<might> have some missing features.
 
-Have a look at the L</SEE ALSO> for references to more documentation, or jump
-right to the L<tutorial|Mojolicious::Plugin::OpenAPI::Guides::Tutorial>.
-
-Currently v2 is very well supported, while v3 should be considered
-EXPERIMENTAL.
+Have a look at the L</SEE ALSO> for references to more documentation.
 
 Please report in L<issues|https://github.com/jhthorsen/json-validator/issues>
 or open pull requests to enhance the 3.0 support.
@@ -582,7 +580,7 @@ plugin.
 
 The name of the "definition" in the spec that will be used for
 L</default_response_codes>. The default value is "DefaultResponse". See
-L<Mojolicious::Plugin::OpenAPI::Guides::Tutorial/"Default response schema">
+L<Mojolicious::Plugin::OpenAPI::Guides::OpenAPIv2/"Default response schema">
 for more details.
 
 =head3 log_level
@@ -622,6 +620,9 @@ C<route> can be specified in case you want to have a protected API. Example:
 Can be used to set a different schema, than the default OpenAPI 2.0 spec.
 Example values: "http://swagger.io/v2/schema.json", "v2" or "v3".
 
+See also L<Mojolicious::Plugin::OpenAPI::Guides::OpenAPIv2> and
+L<Mojolicious::Plugin::OpenAPI::Guides::OpenAPIv3>.
+
 =head3 spec_route_name
 
 Name of the route that handles the "basePath" part of the specification and
@@ -666,15 +667,29 @@ the terms of the Artistic License version 2.0.
 
 =over 2
 
-=item * L<Mojolicious::Plugin::OpenAPI::Guides::Tutorial>
+=item * L<Mojolicious::Plugin::OpenAPI::Guides::OpenAPIv2>
+
+Guide for how to use this plugin with OpenAPI version 2.0 spec.
+
+=item * L<Mojolicious::Plugin::OpenAPI::Guides::OpenAPIv3>
+
+Guide for how to use this plugin with OpenAPI version 3.0 spec.
 
 =item * L<Mojolicious::Plugin::OpenAPI::Cors>
 
+Plugin to add Cross-Origin Resource Sharing (CORS).
+
 =item * L<Mojolicious::Plugin::OpenAPI::Security>
 
+Plugin for handling security definitions in your schema.
+
 =item * L<Mojolicious::Plugin::OpenAPI::SpecRenderer>
 
-=item * L<OpenAPI specification|https://openapis.org/specification>
+Plugin for exposing your spec in human readble or JSON format.
+
+=item * L<https://www.openapis.org/>
+
+Official OpenAPI website.
 
 =back
 
